@@ -34,7 +34,7 @@ def get_stage(provider: Provider) -> Stage:
     try:
         stage = provider.get_stage()
     except ProviderError as e:
-        raise StageError(f"Unable to get stage from {provider}") from e
+        raise StageError(f"Unable to get stage from {provider.name}") from e
     return stage
 
 
@@ -77,7 +77,7 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     try:
         schedule = provider.get_schedule(province=province, suburb=suburb, stage=stage)
     except ProviderError as e:
-        logging.log(logging.DEBUG, "Unable to get schedule from {provider}. {e}".format(provider=provider, e=e))
+        logging.log(logging.DEBUG, "Unable to get schedule from {provider.name}. {e}".format(provider=provider, e=e))
         if cached_schedule:
             return cached_schedule  # best effort
         raise
