@@ -124,14 +124,15 @@ class Eskom(Provider):
                 time_soup = day.find_all("a")
                 for time_tag in time_soup:
                     start_str, end_str = time_tag.get_text().strip().split(" - ")
-                    start = datetime.strptime(start_str, "%H:%M")
-                    end = datetime.strptime(end_str, "%H:%M")
-                    schedule.append((
-                        now.replace(month=date.month, day=date.day, hour=start.hour, minute=start.minute, second=0,
-                                    microsecond=0, tzinfo=sast).astimezone(utc).isoformat(),
-                        now.replace(month=date.month, day=date.day, hour=end.hour, minute=end.minute, second=0,
-                                    microsecond=0, tzinfo=sast).astimezone(utc).isoformat()
-                    ))
+                    start = datetime.strptime(start_str, "%H:%M").replace(
+                        year=date.year, month=date.month, day=date.day, second=0, microsecond=0, tzinfo=sast
+                    ).astimezone(utc)
+                    end = datetime.strptime(end_str, "%H:%M").replace(
+                        year=date.year, month=date.month, day=date.day, second=0, microsecond=0, tzinfo=sast
+                    ).astimezone(utc)
+                    if end < start:
+                        end = end + timedelta(days=1)
+                    schedule.append((start.isoformat(), end.isoformat()))
         except Exception as e:
             raise ProviderError(f"Unable to parse schedule data.") from e
         else:
